@@ -20,7 +20,6 @@ env = environ.Env(
     DJANGO_CRYPTO_FIELDS_TEMP_PATH=(bool, False),
     DJANGO_CSRF_COOKIE_SECURE=(bool, True),
     DJANGO_DEBUG=(bool, False),
-    DJANGO_EDC_BOOTSTRAP=(int, 3),
     DJANGO_EMAIL_ENABLED=(bool, False),
     DJANGO_EMAIL_USE_TLS=(bool, True),
     DJANGO_LIVE_SYSTEM=(bool, False),
@@ -79,12 +78,16 @@ INSTALLED_APPS = [
     "django.contrib.staticfiles",
     "django.contrib.sites",
     "defender",
+    "sequences.apps.SequencesConfig",
     "multisite",
     "fontawesomefree",
     "django_crypto_fields.apps.AppConfig",
-    "django_revision.apps.AppConfig",
+    "django_db_views",
     "django_extensions",
+    "django_pylabels.apps.AppConfig",
+    "django_revision.apps.AppConfig",
     "logentry_admin",
+    "rangefilter",
     "simple_history",
     "storages",
     "edc_action_item.apps.AppConfig",
@@ -128,6 +131,8 @@ INSTALLED_APPS = [
     "edc_prn.apps.AppConfig",
     "edc_protocol.apps.AppConfig",
     "edc_protocol_incident.apps.AppConfig",
+    "edc_pylabels.apps.AppConfig",
+    "edc_qareports.apps.AppConfig",
     "edc_randomization.apps.AppConfig",
     "edc_refusal.apps.AppConfig",
     "edc_registration.apps.AppConfig",
@@ -145,6 +150,7 @@ INSTALLED_APPS = [
     "effect_dashboard.apps.AppConfig",
     "effect_labs.apps.AppConfig",
     "effect_subject.apps.AppConfig",
+    "effect_reports.apps.AppConfig",
     "effect_visit_schedule.apps.AppConfig",
     "effect_ae.apps.AppConfig",
     "effect_auth.apps.AppConfig",
@@ -349,7 +355,6 @@ EDC_DASHBOARD_APP_LABEL = "effect_dashboard"
 EDC_NAVBAR_DEFAULT = env("EDC_NAVBAR_DEFAULT")
 
 # dashboards
-EDC_BOOTSTRAP = env("DJANGO_EDC_BOOTSTRAP")
 DASHBOARD_URL_NAMES = env.dict("DJANGO_DASHBOARD_URL_NAMES")
 DASHBOARD_BASE_TEMPLATES = env.dict("DJANGO_DASHBOARD_BASE_TEMPLATES")
 LAB_DASHBOARD_BASE_TEMPLATES = env.dict("DJANGO_LAB_DASHBOARD_BASE_TEMPLATES")
@@ -388,7 +393,7 @@ SILENCED_SYSTEM_CHECKS = ["sites.E101"]
 # and that redis server is running
 DEFENDER_REDIS_NAME = "default"
 DEFENDER_LOCK_OUT_BY_IP_AND_USERNAME = True
-DEFENDER_LOCKOUT_TEMPLATE = "edc_auth/bootstrap3/login.html"
+DEFENDER_LOCKOUT_TEMPLATE = "edc_auth/login.html"
 DEFENDER_LOGIN_FAILURE_LIMIT = 5
 
 # edc_crf
@@ -480,7 +485,7 @@ if env("AWS_ENABLED"):
     AWS_S3_OBJECT_PARAMETERS = {"CacheControl": "max-age=86400"}
     AWS_LOCATION = env.str("AWS_LOCATION")
     AWS_IS_GZIPPED = True
-    STATICFILES_STORAGE = "storages.backends.s3boto3.S3Boto3Storage"
+    STORAGES = {"staticfiles": {"BACKEND": "storages.backends.s3boto3.S3Boto3Storage"}}
     STATIC_URL = f"{os.path.join(AWS_S3_CUSTOM_DOMAIN, AWS_LOCATION)}/"
     STATIC_ROOT = ""
 else:
