@@ -6,7 +6,7 @@ from edc_randomization.site_randomizers import site_randomizers
 
 
 class HomeView(EdcViewMixin, NavbarViewMixin, TemplateView):
-    template_name = f"effect_edc/bootstrap{settings.EDC_BOOTSTRAP}/home.html"
+    template_name = "effect_edc/home.html"
     navbar_name = settings.APP_NAME
     navbar_selected_item = "home"
 
